%DATA_BROWSER  access and analysis of gravitational antenna data
%
%                 D_B  structure
%
%     D_B.access           "by file", "by time"
%     D_B.data.type        1: snf, 2: frames, 3: R87, 4: A.V. format, 100: simulation
%     D_B.data.file        selected file (spectrum file for simulation)
%     D_B.data.initim      initial time
%     D_B.data.duration    duration
%     D_B.data.chname      channel name
%     D_B.data.chnumber    channel number
%     D_B.data.dt          sampling time
%     D_B.data.dlen        data length
%     D_B.data.sp          spectrum vector
%     D_B.filter           an ff_struct (frequency filter structure)
%     D_B.proc.type        rplot   : running plot
%                          rpows   : running power spectrum
%                          tfpows  : time-frequency power spectrum
%                          rhist   : running histograms
%                          evenf   : event finder
%                          summary : data resume` (only for some data types)
%                          extrgd  : extracts data to a gd
%                          dtfpows : time-frequency innovation power spectrum
%     D_B.proc.iter        iterations
%     D_B.notyet           = 1 -> not yet implemented feature
%                          = 2 -> not available for this case

% Version 1.0 - April 1999
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% Copyright (C) 1999  Sergio Frasca - sergio.frasca@roma1.infn.it
% Department of Physics - Universita` "La Sapienza" - Rome

snag_local_symbols;

dataString=[...
'[ntype,file]=fr_fildatsel;' ...
'D_B.data.type=ntype;' ...
'D_B.data.file=file;' ...
...
'[chn,chs,dt,dlen,sp]=fr_selch(ntype,file);' ...
'D_B.data.chname=chs;' ...
'D_B.data.chnumber=chn;' ...
'D_B.data.dt=dt;' ...
'D_B.data.dlen=dlen;' ...
'D_B.data.sp=sp;' ...
'if ntype == 100; D_B.data.file=chs; end;'];

appo=who('D_B');
if length(appo) <= 0
   D_B.access='by file';
   D_B.data.type=100;
   D_B.data.file='nofile';
   D_B.data.initim=0;
   D_B.data.duration=1000000;
   D_B.data.chname=' ';
   D_B.data.chnumber=0;
   D_B.filter.n=0;
   D_B.filter.capt='no filters';
   D_B.proc.type='tfpows';
   D_B.proc.iter=20;
   
   eval(dataString);
end

text=d_b_show(D_B);


text=d_b_show(D_B);

figNumber=figure( ...
    'Name','Snag Data Browser', ...
    'NumberTitle','off', ...
    'Color',[1 1 0.7],...
    'MenuBar','none',...
    'Visible','off');

%===================================
% Set up the D_B Window
top=0.95;
left=0.25;
right=0.95;
bottom=0.05;
labelHt=0.05;
spacing=0.005;
promptStr=text;

% First, the Snag Window frame
frmBorder=0.02;
frmPos=[left-frmBorder bottom-frmBorder ...
    (right-left)+2*frmBorder (top-bottom)+2*frmBorder];
uicontrol( ...
    'Style','frame', ...
    'Units','normalized', ...
    'Position',frmPos, ...
    'BackgroundColor',[0.50 0.50 1]);
% Then the text label
labelPos=[left top-labelHt (right-left) labelHt];
uicontrol( ...
    'Style','text', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',[0.50 0.50 1], ...
    'ForegroundColor',[1 1 1], ...
    'String','Data Browser window');
% Then the text field
mcwPos=[left bottom (right-left) top-bottom-labelHt-spacing];
mcwHndl=uicontrol( ...
    'Style','text', ...
    'HorizontalAlignment','left', ...
    'Units','normalized', ...
    'Max',10, ...
    'BackgroundColor',[1 1 1], ...
    'Position',mcwPos, ...
    'String',promptStr);
% Save this handle for future use
set(gcf,'UserData',mcwHndl);

%====================================
% Information for all buttons
labelColor=[0.8 0.8 0.8];
top=0.95;
left=0.80;
btnWid=0.15;
btnHt=0.08;
% Spacing between the button and the next command's label
spacing=0.027;

%====================================
% The buttons

left=0.04;
yPos=0.85;
hSpac=0.03;

btnPos=[left yPos btnWid btnHt];
callbackStr='notyet(''Access type'')';

uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',[0.70 0.70 1], ...
    'String','Access type', ...
    'Callback',callbackStr);
 
yPos=yPos-btnHt-hSpac;
btnPos=[left yPos btnWid btnHt];
callbackStr='eval(dataString);text=d_b_show(D_B);set(mcwHndl,''string'',text);';

uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',[0.70 0.70 1], ...
    'String','Data', ...
    'Callback',callbackStr);
 
yPos=yPos-btnHt-hSpac;
btnPos=[left yPos btnWid btnHt];
%callbackStr='notyet(''Filtering'')';
callbackStr=['D_B.filter=set_ff_struct(''file'');' ...
      'text=d_b_show(D_B);set(mcwHndl,''string'',text);'];

uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',[0.70 0.70 1], ...
    'String','Filtering', ...
    'Callback',callbackStr);
 
yPos=yPos-btnHt-hSpac;
btnPos=[left yPos btnWid btnHt];
callbackStr='d_b_procmenu;text=d_b_show(D_B);set(mcwHndl,''string'',text);';

uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',[0.70 0.70 1], ...
    'String','Processing', ...
    'Callback',callbackStr);
% Now uncover the figure
set(figNumber,'Visible','on');
 
yPos=yPos-btnHt-2*hSpac;
btnPos=[left yPos btnWid btnHt];
callbackStr=['[out_db,D_B]=go_db(D_B);' ...
   'if D_B.notyet == 0;' ...
   ' answ=inputdlg({''New name of out_db ?''},' ...
   '''Renaming the output object'',1,{''out_db''});' ...
   'eval([answ{1} ''=out_db'']);' ...
   'end'];

uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',[1 0.5 0.5], ...
    'String','Go !', ...
    'Callback',callbackStr);
% Now uncover the figure
set(figNumber,'Visible','on');
 
yPos=yPos-btnHt-2*hSpac;
btnPos=[left yPos btnWid btnHt];
callbackStr='web([snagdir ''doc/db/db.htm''])';

uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',[0.70 1 0.70], ...
    'String','Help', ...
    'Callback',callbackStr);
% Now uncover the figure
set(figNumber,'Visible','on');
 
yPos=yPos-btnHt-hSpac;
btnPos=[left yPos btnWid btnHt];
callbackStr=' ';

uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',[0.70 0.70 1], ...
    'String','Snag', ...
    'Callback','snag');
% Now uncover the figure
set(figNumber,'Visible','on');

%hold off;
