function [par,sig,nois,zer]=NC1_read(addr,ant,runame,head,band,plt)
% reads data from NC1 file collection
%
%    [out,par]=NC1_read(addr,ant,runame,head,band)
%
%   addr,ant,runame  as for bsd_lego
%   head     file name header (ex.: 'GC')
%   band     min,max frequency
%   plt      > 0, plots

% Snag Version 2.0 - May 2020
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni, S.D'Antonio and S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

if ~exist('plt','var')
    plt=0;
end

switch ant
    case 'ligoh'
        A='H';
    case 'ligol'
        A='L';
    case 'virgo'
        A='V';
end

fil1=['NC1_' head '_' runame '_' A '_'];
sel=[addr dirsep() fil1]
eval(['list=dir(''' sel '*'')']);

lenfil1=length(fil1);
nfil=length(list);

ii=0;

for i = 1:nfil
    ini(i)=sscanf(list(i).name(lenfil1+1:lenfil1+4),'%4d');
    fin(i)=sscanf(list(i).name(lenfil1+6:lenfil1+9),'%4d');
    sel(i)=1;
    if band(1) >= fin(i)
        sel(i)=0;
    end
    if band(2) <= ini(i)
        sel(i)=0;
    end
    if sel(i) == 1
        ii=ii+1;
        fils{ii}=[list(i).folder dirsep() list(i).name];
    end
end

nsel=length(fils);

par.fils=fils;

for i = 1:nsel
    eval(['load ' fils{i}])
    band1=round(sidsw.band);
    ini1=1;
    if i == 1
        DFR=sidsw.DFR;sidsw
        frdel=sidsw.frdel;
        wband=band(2)-band(1);
        n=length(sidsw.sidsig);
        N=ceil(wband/DFR);
        sidsig=zeros(1,N);
        sidnois=sidsig;
        iczer=0;
        if isfield(sidsw,'sidzer')
            sidzer=sidsig;
            iczer=1;
        else
            zer=0;
        end
        ini1=round((band(1)-band1(1))/DFR)+1; %band,band1
        iniout=1;
    end
    fin1=n;
    if i == nsel
        fin1=n-round((band1(2)-band(2))/DFR);
    end
    nout1=fin1-ini1+1;%iniout,ini1,fin1
    sig(iniout:iniout+nout1-1)=sidsw.sidsig(ini1:fin1);
    nois(iniout:iniout+nout1-1)=sidsw.sidnois(ini1:fin1);
    if iczer
        zer(iniout:iniout+nout1-1)=sidsw.sidzer(ini1:fin1);
    end
    
    iniout=iniout+nout1;
end

sig=gd(sig);
sig=edit_gd(sig,'ini',band(1)+frdel,'dx',DFR);
nois=gd(nois);
nois=edit_gd(nois,'ini',band(1)+frdel,'dx',DFR);
if iczer
    zer=gd(zer);
    zer=edit_gd(zer,'ini',band(1)+frdel,'dx',DFR);
end

if plt > 0
    figure,semilogy(sig),grid on,title([ant ' sig']),xlabel('Hz')
    figure,semilogy(nois),grid on,title([ant ' nois']),xlabel('Hz')
    figure,semilogy(zer),grid on,title([ant ' zer']),xlabel('Hz')
end