function [sids,bsdsstr]=NC_sid_sweep_multi_0(bsdsstr,freq,direc,sband,nsid)
% multi antenna sid_sweep candidates
%
%   sids=sid_sweep_multi(bsdsstr,freq,direc,sband,nsid)
%
%   bsdsstr  bsd search structure array (with addr,ant,runame  as for bsd_lego)
%             if it is a cell array containing bsds, use them
%   freq     candidate frequency;
%             if 2-dim freq(2), spin-down
%             if 3-dim freq(3) is the semiband; def semiband 0.5 Hz
%   direc    direction structure
%   sband    search band (in units of 1/SD; typically 20) sband=0 -> [20,5]
%              if present sband(2) = interlacing delay (in 1/SD)
%              sband(3) = enlargement factor (def enl=1)
%   nsid     number of sidereal bins (def or 0 = round(SD/outsid.DT))
%   iout     if present and >0, serial numbers (J) for outputting data (output channels) if negative check version
%            (1)=-1 out ff
%            (1)=-2 out ff (iout2:iout3)
%            (1)=-3 out POW
%            (1)=-4 out POW (iout2:iout3)

% Snag Version 2.0 - Apr 2020
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni, S.D'Antonio and S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

%% base parameters

if ~exist('nsid','var')
    nsid=0;
end

if length(freq) == 1
    freq(2)=0;
end

if length(freq) <= 2
    freq(3)=0.5;
end

%% data bsds

n=length(bsdsstr);
if ~iscell(bsdsstr)
    for k = 1:n
        kk=num2str(k);
        addr=bsdsstr(k).addr;
        ant=bsdsstr(k).ant;
        runame=bsdsstr(k).runame;
        band=freq(1)+[-0.5 0.5];
        eval(['bsdsstr1{' kk '}=bsd_lego(addr,ant,runame,1,band,2);'])
    end
    bsdsstr=bsdsstr1;
    save('bsdscell','bsdsstr')
end

for k = 1:n
    [~,pars]=is_bsd(bsdsstr{k});
    if k == 1
        tin=pars.tin;
        tfi=pars.tfi;
    else
        tin=min(tin,pars.tin);
        tfi=max(tfi,pars.tfi);
    end
    sidpars.ant{k}=pars.ant;
end

sidpars.tin=tin;
sidpars.tfi=tfi;
sidpars.epoch=floor((tin+tfi)/2);

if length(sband) > 1
    interl=sband(2);
    if length(sband) > 2
        enl=sband(3);
    end
    sband=sband(1);
else
    interl=sband/2;
end

direc.f0=freq(1);
direc.df0=freq(2);
direc.ddf0=0;

%% sid sweeps

for k = 1:n
    fprintf('\n    %s    %s \n\n',sidpars.ant{k},direc.name)
    [bsds_corr{k},frcorr]=bsd_dopp_sd(bsdsstr{k},direc);
    bsds_corr{k}=cut_bsd(bsds_corr{k},[tin,tfi],1);
    sids{k}=NC_sid_sweep_base_0(bsds_corr{k},freq,direc,sband,nsid);
    sids{k}.frcorr=frcorr;
end

sids{n+1}=sidpars;