function fr1=doppler_norot(time,fr0,alpha,delta,coord)
%DOPPLER_NOROT  computes the Doppler shifted frequency WITHOUT EARTH ROTATION
%
%        fr1=doppler_norot(time,fr0,alpha,delta,coord)
%
%   time           serial date-time (mjd; array)
%   fr0            original frequency(-ies)
%   alpha,delta    source coordinates (in degrees, the type defined by coord)
%   coord          = 0 -> equatorial, = 1 -> ecliptic

deg_to_rad=pi/180;
time=time(:);
fr0=fr0(:)';

if ~exist('coord','var')
    coord=0;
end

if coord == 1
    [alpha,delta]=astro_coord('ecl','equ',alpha,delta);
end

[ae,de,v]=earth_v2(time);

as=alpha*deg_to_rad;
ds=delta*deg_to_rad;

cosfi=(cos(as).*cos(ae)+sin(as).*sin(ae)).*cos(ds).*cos(de)+sin(ds).*sin(de);

fr1=(1+cosfi.*v)*fr0;


