function gw_ana
%GW_ANA   gw antenna data analysis gui

% Version 1.0 - March 1999
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% Copyright (C) 1999  Sergio Frasca - sergio.frasca@roma1.infn.it
% Department of Physics - Universita` "La Sapienza" - Rome

figNumber=figure( ...
    'Name','GW data analysis', ...
    'NumberTitle','off', ...
    'Visible','off');

%===================================
% Set up the selection and pre-processing frames

labelHt=0.08;
spacing=0.02;
eps=0.005;

vertfr=.455;
horifr=.6;
vdist=vertfr+spacing;
frmBorder=0.02;
biasfr=frmBorder;

% Filtering

frmPos=[frmBorder biasfr ...
      horifr vertfr];
bckcol=[0.50 0.70 0.50];
uicontrol( ...
    'Style','frame', ...
    'Units','normalized', ...
    'Position',frmPos, ...
    'BackgroundColor',bckcol);
 
top=biasfr+vertfr;
labelPos=[frmBorder+eps top-labelHt-eps horifr/2 labelHt];
uicontrol( ...
    'Style','text', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',14, ...
    'String','Filtering');
 
frmPos=[frmBorder+7*horifr/12-2*eps top-labelHt-3*eps horifr/3 labelHt];
uicontrol( ...
   'Style','popupmenu', ...
   'String',{'No' 'Chirp' 'Continuous signals' 'Stochastic background'}, ...
   'Units','normalized', ...
   'Position',frmPos, ...
   'BackgroundColor',[1 1 1]);

btnPos=[frmBorder+horifr/12 top-2*labelHt+eps horifr*0.3 labelHt*0.7];
callbackStr='creagd';
uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'String','set parameters', ...
    'Callback',callbackStr);

btnPos=[frmBorder+7*horifr/12 top-2*labelHt+eps horifr*0.3 labelHt*0.7];
callbackStr='creagd';
uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',bckcol.*0.7, ...
    'ForegroundColor',[1 1 0], ...
    'String','set default', ...
    'Callback',callbackStr);
 
% Data selection

biasfr=biasfr+vdist;
frmPos=[frmBorder biasfr ...
      horifr vertfr];
bckcol=[0.50 0.70 0.50];
uicontrol( ...
    'Style','frame', ...
    'Units','normalized', ...
    'Position',frmPos, ...
    'BackgroundColor',bckcol);
 
top=biasfr+vertfr;
labelPos=[frmBorder+eps top-labelHt-eps horifr/2 labelHt];
uicontrol( ...
    'Style','text', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',14, ...
    'String','Data selection');
 
frmPos=[frmBorder+7*horifr/12-2*eps top-labelHt-3*eps horifr/3 labelHt];
uicontrol( ...
   'Style','popupmenu', ...
   'String',{'No' 'Delta' 'Standard collapse' 'Ringing collapse'}, ...
   'Units','normalized', ...
   'Position',frmPos, ...
   'BackgroundColor',[1 1 1]);

btnPos=[frmBorder+horifr/12 top-2*labelHt+eps horifr*0.3 labelHt*0.7];
callbackStr='creagd';
uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'String','set parameters', ...
    'Callback',callbackStr);

btnPos=[frmBorder+7*horifr/12 top-2*labelHt+eps horifr*0.3 labelHt*0.7];
callbackStr='creagd';
uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',bckcol.*0.7, ...
    'ForegroundColor',[1 1 0], ...
    'String','set default', ...
    'Callback',callbackStr);
 

%===================================
% Set up the processing frames

spacing=0.02;
biasho=horifr+frmBorder;

vertfr=.297;
horifr=.33;
vdist=vertfr+spacing;
frmBorder=0.02;
biasfr=frmBorder;

% Start & Show

frmPos=[frmBorder+biasho biasfr ...
      horifr vertfr];
bckcol=[0.50 0.50 0.77];
uicontrol( ...
    'Style','frame', ...
    'Units','normalized', ...
    'Position',frmPos, ...
    'BackgroundColor',bckcol);
 
top=biasfr+vertfr;
labelPos=[frmBorder+biasho+eps top-labelHt-eps horifr/2 labelHt];
uicontrol( ...
    'Style','text', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',12, ...
    'String','Start & Show');

btnPos=[frmBorder+biasho+2*horifr/10 top-1.7*labelHt horifr*0.6 labelHt*0.7];
callbackStr='creagd';
uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',bckcol.*0.7, ...
    'ForegroundColor',[1 1 0], ...
    'String','show parameters', ...
    'Callback',callbackStr);

btnPos=[frmBorder+biasho+1*horifr/10 top-3*labelHt horifr*0.3 labelHt*0.7];
callbackStr='creagd';
uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',bckcol.*0.7, ...
    'ForegroundColor',[1 1 0], ...
    'String','start', ...
    'Callback',callbackStr);

btnPos=[frmBorder+biasho+6*horifr/10 top-3*labelHt horifr*0.3 labelHt*0.7];
callbackStr='creagd';
uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',bckcol.*0.7, ...
    'ForegroundColor',[1 1 0], ...
    'String','stop', ...
    'Callback',callbackStr);
 
% Processing
 
biasfr=biasfr+vdist;
frmPos=[frmBorder+biasho biasfr ...
      horifr vertfr];
bckcol=[0.50 0.50 0.77];
uicontrol( ...
    'Style','frame', ...
    'Units','normalized', ...
    'Position',frmPos, ...
    'BackgroundColor',bckcol);
 
top=biasfr+vertfr;
labelPos=[frmBorder+biasho+eps top-labelHt-eps horifr/2 labelHt];
uicontrol( ...
    'Style','text', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',12, ...
    'String','Processing');

btnPos=[frmBorder+biasho+2*horifr/10 top-1.7*labelHt horifr*0.6 labelHt*0.7];
callbackStr='creagd';
uicontrol( ...
    'Style','listbox', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',bckcol.*0.7, ...
    'ForegroundColor',[1 1 0], ...
    'String',{'spectrum' 'histogram' 'oscilloscope' 'events' 'statistics'}, ...
    'Callback',callbackStr);

btnPos=[frmBorder+biasho+2*horifr/10 top-3*labelHt horifr*0.6 labelHt*0.7];
callbackStr='creagd';
uicontrol( ...
    'Style','pushbutton', ...
    'Units','normalized', ...
    'Position',btnPos, ...
    'BackgroundColor',bckcol.*0.7, ...
    'ForegroundColor',[1 1 0], ...
    'String','set parameters', ...
    'Callback',callbackStr);
 
% Data stream
 
biasfr=biasfr+vdist;
frmPos=[frmBorder+biasho biasfr ...
      horifr vertfr];
bckcol=[0.50 0.50 0.77];
uicontrol( ...
    'Style','frame', ...
    'Units','normalized', ...
    'Position',frmPos, ...
    'BackgroundColor',bckcol);
 
top=biasfr+vertfr;
labelPos=[frmBorder+biasho+eps top-labelHt-eps horifr/2 labelHt];
uicontrol( ...
    'Style','text', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',12, ...
    'String','Data stream');
 
top=biasfr+vertfr;
labelPos=[frmBorder+biasho+horifr/2 top-1.5*labelHt horifr/2.2 labelHt/1.5];
uicontrol( ...
    'Style','edit', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',12, ...
    'String','4096');
 
top=biasfr+vertfr;
labelPos=[frmBorder+biasho+eps top-1.5*labelHt horifr/2.2 labelHt/1.5];
uicontrol( ...
    'Style','text', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',12, ...
    'String','chunk length');
 
top=biasfr+vertfr;
labelPos=[frmBorder+biasho+horifr/2 top-2.5*labelHt horifr/2.2 labelHt/1.5];
uicontrol( ...
    'Style','edit', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',12, ...
    'String','100000');
 
top=biasfr+vertfr;
labelPos=[frmBorder+biasho+eps top-2.5*labelHt horifr/2.2 labelHt/1.5];
uicontrol( ...
    'Style','text', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',12, ...
    'String','N. of chunks');
 
top=biasfr+vertfr;
labelPos=[frmBorder+biasho+horifr/2 top-3.5*labelHt horifr/2.2 labelHt/1.5];
uicontrol( ...
   'Style','togglebutton', ...
   'Units','normalized', ...
   'Position',labelPos, ...
   'BackgroundColor',bckcol, ...
   'ForegroundColor',[1 1 0], ...
   'FontSize',12, ...
   'String','interlace');
 
top=biasfr+vertfr;
labelPos=[frmBorder+biasho+eps top-3.5*labelHt horifr/2.2 labelHt/1.5];
uicontrol( ...
    'Style','text', ...
    'Units','normalized', ...
    'Position',labelPos, ...
    'BackgroundColor',bckcol, ...
    'ForegroundColor',[1 1 0], ...
    'FontSize',12, ...
    'String','interlacing');

% Now uncover the figure
set(figNumber,'Visible','on');



