function [bsd_out,BSD_tab_out,stpar]=bsd_equilego(addr,tab,tim,freq,parants,modif,modifpost)
% data access alternative to bsd_lego
%   good for any subband and more months
% 
%   limits:
%      no modes (there are two automatic modes)
%      out band could be any integer submultiple of the fullband,
%      but should be inside 2 adjacent basic BANDs
%
%     [bsd_out,BSD_tab_out,stpar]=bsd_equilego(addr,tab,tim,freq,len,modif,modifpost)
%
%    addr      path that contains BSD data master directory without the final dirsep
% %                or structure with all the input parameters as fields
%    tab       BSD table (charged) or just the name (char)
%    tim       [tini tfin] (mjd) ; if length(tim) = 1 or tini=tfin the whole run
%              [tini tfin dt0] if the sampling time dt0 of the BSD collection is not 0.1 s
%    freq      [frini frfin] ; if length(freq) = 1 or frini=frfin the full band with frini (def ortho-band)
%               (freq is the requested band, band will contain the effective band)
%    parants   antenna set parameters; = 0 -> no antenna set parameter used; > 2 imposed Dt_max
%    modif     (if present) modification structure: modifies accessed primary files
%              e.g. adding signals or sources; see bsd_acc_modif
%              [] no modification
%    modifpost (if present) modification after the band extraction

% Snag Version 2.0 - February 2021
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni and S. Frasca - sergio.frasca@roma1.infn.it
% Department of Physics - Sapienza University - Rome

if ~exist('parants','var')
    parants=0;
end

if isnumeric(parants)
    if parants > 2
        Dt_max=parants;
    end
    parants=struct();
    parants.equifreq=0;
    parants.frshift=0;
    parants.prlemod=1;
end

if ischar(tab)
    load([addr dirsep 'BSD' dirsep tab])
    eval(['tab=' tab ';'])
end

FRMIN=min(tab.fr_ini);
FRMAX=max(tab.fr_fin);

if length(tim) == 3
    dt0=tim(3);
else
    dt0=0.1;
end

if length(tim) > 1
    if tim(1) == tim(2)
        tim=1;
    end
end

if length(freq) > 1
    freq(2)=freq(2)-1000*eps;  % ATTENTION ! WORKAROUND
    if freq(1) == freq(2)
        freq=freq(1);
    end
end

bsd_out=0;
icmodif=0;

if exist('modif','var')
    icmodif=1;
else 
    modif=[];
end
freq
if freq(1) < FRMIN | freq(2) > FRMAX
    fprintf(' *** Out of BSD data band  -  freq %f %f\n',freq)
    stpar.error=sprintf(' *** Out of BSD data band  -  freq %f %f',freq)
    bsd_out=0;
    BSD_tab_out=0;
    return
end
    
[BSD_tab_out,subtab]=bsd_subtab(tab,tim,freq,dt0);subtab %---------------

stpar.subtab=subtab;
if isfield(parants,'frshift')
    stpar.frshift=parants.frshift;
else
    stpar.frshift=0;
end

stpar.t_ini=unique(BSD_tab_out.t_ini(:));
stpar.t_fin=unique(BSD_tab_out.t_fin(:));%parants,disp('ciao')

if parants.equifreq == 0 
    Dt_max1=stpar.t_fin-stpar.t_ini;
    if ~exist('Dt_max','var') 
        Dt_max=max(Dt_max1(:));
    end
    stpar.T_ini=min(stpar.t_ini);
    stpar.T_fin=max(stpar.t_fin);
else
    stpar.T_ini=parants.T_ini;
    stpar.T_fin=parants.T_fin;
    Dt_max=parants.Dt_max;
end

stpar.Dt_max=Dt_max; parants

prle=pre_equilego(freq,Dt_max,parants.prlemod,dt0)   %---------------

stpar.P_R_L_E=prle;
stpar.bandout=prle.bandout;
stpar.band=prle.bandout;
stpar.prlemod=parants.prlemod;
NRL=prle.NRL;
stpar.dt1=prle.dt1;
stpar.dt00=prle.dt00;
stpar.dt0=prle.dt0;
stpar.Nfft=NRL;
stpar.lenout=prle.lenout;
stpar.if1=prle.iniband;
stpar.if2=prle.finband;
stpar.fact=prle.fact;

stpar.tsbase=0;
mode=1;
if subtab.n_f == 2
    mode=2;
end
if subtab.n_f > 2
    error(' *** Range too large')
end
    
stpar.st_t_ini=BSD_tab_out.t_ini;
stpar.st_t_fin=BSD_tab_out.t_fin;
stpar.st_n=(stpar.st_t_fin-stpar.st_t_ini)*86400/dt0+1;

if exist('modif','var')
    stpar.modif=modif;
end
if exist('modifpost','var')
    stpar.modifpost=modifpost;
end

[bsd_out,stpar]=equi_collect(addr,BSD_tab_out,stpar);    %---------------

cont=cont_gd(bsd_out);
[zhole, shole]=bsd_holes(bsd_out);
cont.tfstr.zeros=shole;
bsd_out=edit_gd(bsd_out,'cont',cont);
