function [parants,Dt_max]=check_bsdsstr(bsds_addr_tab,dt0)
% checks bsd tab structures (useful fot more antennas)
%
%   bsds_addr_tab   bsds tab structure as
%                         addr='E:';
%                         bsds_addr_tab(1).addr=addr;
%                         bsds_addr_tab(1).tab=BSD_O3_L;
%                         bsds_addr_tab(2).addr=addr;
%                         bsds_addr_tab(2).tab=BSD_O3_H;
%                         bsds_addr_tab(3).addr=addr;
%                         bsds_addr_tab(3).tab=BSD_O3_V;
%                   or string array, as ["F:";"BSD_O3_L"]
%   dt0             basic sampling time

% Snag Version 2.0 - April 2021
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni and S. Frasca - sergio.frasca@roma1.infn.it
% Department of Physics - Sapienza University - Rome

if ~exist('dt0','var')
    dt0=0.1;
end
parants.dt0=dt0;

if isstring(bsds_addr_tab)
    str=bsds_addr_tab;
    clear bsds_addr_tab
    bsds_addr_tab.addr=char(str(1));
    bsds_addr_tab.tab=char(str(2));
end

nant=length(bsds_addr_tab);
parants.nant=nant;

for k = 1:nant
    addr=bsds_addr_tab(k).addr;
    tab1=bsds_addr_tab(k).tab;
    parants.tabname{k}=tab1;
    load([addr dirsep 'BSD' dirsep tab1])
    eval(['tab=' tab1 ';'])
    t_ini(k,:)=tab.t_ini;
    t_fin(k,:)=tab.t_fin;
    fr_ini(k,:)=tab.fr_ini;
    fr_fin(k,:)=tab.fr_fin;
    parants.tab{k}=tab;
    parants.nfiles(k)=length(t_ini(k,:));
    parants.N(k)=length(unique(t_ini(k,:)));
    parants.t_ini1(k,:)=unique(t_ini(k,:));
    parants.fr_ini1(k,:)=unique(fr_ini(k,:));
end

parants.t_ini=t_ini;
parants.t_fin=t_fin;
Dt_max=t_fin-t_ini;
parants.Dt_max=max(Dt_max(:));
parants.len=round(parants.Dt_max*86400/dt0+1);
parants.fr_ini=fr_ini;
parants.fr_fin=fr_fin;

parants.T_ini=min(t_ini(:));
parants.T_fin=max(t_fin(:));
parants.T_mean=(parants.T_ini+parants.T_fin)/2;
parants.T_obs=parants.T_fin-parants.T_ini;

parants.FR_ini=max(fr_ini(:,1));
parants.FR_fin=min(fr_fin(:,end));

Dt_max=parants.Dt_max;