function [g, y, itimes, headers]=create_BSD_Snag(sfdblist,foldout,frmin,frmax,BSD_BAND,nfft,run,ant,calibration,sim,notes)
%[g, y, itimes, headers]=sfdb09_2bandgds_BSD(sfdblist,foldout,frmin,frmax,band,nfft,run,ant,calibration,sim)
% Example: sfdb09_2bandgds_BSD('sfdblist.txt',pwd,60,80,10,200,'O1','ligoh','C01',0); --> use real data; 
%
%SFDB09_2BANDGDS  creates BSD gds
%    
%   sfdblist     input file list of SFDB 
%   foldout      output BSD gds folder
%   frmin,frmax  operation range (depends on the number of gds to manage simultaneously, usually 10 bands)
%                 (for one gd 210 MB are needed)
%   BSD_BAND     frequency bandwidth (and inverse of the sampling time)
%  
%   nfft         number of fft to use (if it is bigger than the total number of ffts in a SFDB file it uses all the ffts in the SFDB file) 
%   run          e.g 'O1','VSR4'
%   ant          e.g 'ligoh', 'ligol', 'virgo'
%   calibration string e.g. 'C00' or 'C01' indicates the calibration version
%
%   sim           =1 simulation of a sinusoid (no data)
%                 diverso da 2 e 1 usa i dati veri altrimenti una sinusoide al posto dei dati 
%                 =2 simulation of a sinusoid in the data
%                 =3 uses a different sampling frequency
%                 (def. 0)
%   notes         free text string for comments about data (Eg "gated")


% HEADER FFT
% header.einstein=fread(fid,1,'float32');  %
% header.detector=fread(fid,1,'int32');    % detector (0,1)
% header.tsamplu=fread(fid,1,'double');    % original sampling time
% header.typ=fread(fid,1,'int32');         % interlacing (0, 2)
% header.wink=fread(fid,1,'int32');        % window type
% header.nsamples=fread(fid,1,'int32');    % number of samples of fft
% header.tbase=fread(fid,1,'double');      % length of fft in s
% header.deltanu=fread(fid,1,'double');    % fft frequency bin
% header.firstfrind=fread(fid,1,'int32');  % first index (e.g.: 0)
% header.frinit=fread(fid,1,'double');     % initial frequency 
% header.normd=fread(fid,1,'float32');       % factor |fft|^2 -> pow spect
% header.normw=fread(fid,1,'float32');       % factor window (to be multiplied for normd)
% header.red=fread(fid,1,'int32');         % reduction factor (very short spectrum)

% Version 3.0 - April 2016
%
% From Ornella J. Piccinni and Sergio Frasca
% Department of Physics - Universita' "Sapienza" - Rome



tic
if(sim==3)
dtout=1/(2*BSD_BAND); %uses the normal analytic signal 
else
dtout=1/BSD_BAND; %uses the reduced-analytic signal. The sampling frequency is the inverse of the bandwidth
end
% BDS_MINFR=0;
% BDS_MAXFR=1000;


ngds=round((frmax-frmin)/BSD_BAND);% number of simultaneously bsd to handle

%out.start=datestr(now);

if ~exist('foldout','var')
    foldout='';
end

if ~exist('notes','var')
    notes='';
end

%
fidlist=fopen(sfdblist); %the list of files must contain the entire filepath
tline=fgetl(fidlist); 
nfil=0;
%gd_iname=strcat(tline(1),'_',calibration,'_',tline(21:35)); % L_C00_20151501_074107 parte iniziale del nome del gd
%gd_iname=strcat(tline(1:14));
[~,gd_iname,~] = fileparts(tline);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%handling of the BSD final name can change for a different calibration, antenna or
%run
switch run
    case 'O1'
        gd_iname=gd_iname(1:14)
    case 'O2'
        switch  ant
            case 'virgo'

                gd_iname=gd_iname(1:29) % e.g. V1_Hrec_hoft_16384Hz_20170801
            otherwise
                 switch calibration
                     case 'C02'
                         gd_iname=gd_iname(1:14)
                     otherwise
                        gd_iname=gd_iname(1:21)
                end
        end
    case 'O3'
        switch  ant
            case 'virgo'
             %   gd_iname=gd_iname(1:29) % e.g. V1_Hrec_hoft_16384Hz_20170801
                switch calibration
                     case 'C02'
                         gd_iname=gd_iname(1:14)
                     case 'C00'
                         gd_iname=gd_iname(1:29)
                     otherwise
                        gd_iname=gd_iname(1:29)
                end
            otherwise
                 switch calibration
                     case 'C02'
                         gd_iname=gd_iname(1:14)
                     case 'C00'
                         gd_iname
                         gd_iname=strcat([gd_iname(1),'_',calibration,'_',gd_iname(21:28)])
                         gd_iname
                     case 'C01'
                         gd_iname
                         gd_iname=strcat([gd_iname(1),'_',calibration,'_',notes,'_',gd_iname(39:46)])
                         gd_iname
                     otherwise
                        gd_iname=gd_iname(1:21)
                end
        end
        
    case 'VSR2'
        gd_iname=gd_iname(1:17)
    otherwise 
        gd_iname=gd_iname(1:17)
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gd_iname = strrep(gd_iname,':','_');

%%%%%%%%Log file infos (not complete) add infos%%%%%%%
tstr=snag_timestr(now);

foldout, tstr
fidlog=fopen([foldout 'create_BSD_' tstr '.log'],'w');
fidlog

fprintf(fidlog,'Operating on file list %s at %s \n\n',sfdblist,tstr);
fprintf(fidlog,'[g, y, fftarray, itimes]=create_BSD(%s,%s,%f,%d,%d,%d,%s,%f) \n\n',sfdblist,foldout,dtout,frmin,frmax,nfft,run,sim);
%%%%%%%%%%%%%%end of log file %%%%%%

while tline ~= -1
    nfil=nfil+1;
    filep{nfil}=tline;
    tline=fgetl(fidlist);
end


%inizialization of the g matrix which will contain the final time series
%[the final size can be different]
MAX_LEN=max(31,nfil)*BSD_BAND*86400+100000; %31 gg *10 band freq*86400 +100000
g=zeros(ngds,MAX_LEN);  % 
imax=0;

freq12=[frmin:BSD_BAND:(frmax-BSD_BAND); (frmin+BSD_BAND):BSD_BAND:(frmax)]'; %band freq array

%freq12=[100 190;110 200] 

kchunk=0;

for i = 1:nfil                                  %for each SFDB09 file
    file=filep{i};
    disp(file)

    fidp=fopen(file);

    if fidp <= 0
        disp([file ' not opened'])
        %header=0;
%         data=0;
        return
    else
        fprintf('File %s opened, fid %d \n',file,fidp)
    end
    
    ii=0;
       
    while  (~feof(fidp) && ii<nfft)     % ii< nfft %o eof header.eof~=0 feof(fidp) Ã¨ 0 se il file non Ã¨ finito, se Ã¨ diverso da zero siamo arrivati a fine file % ii indice del blocco
        
    
        [header,~,~,sft]=pia_read_block_09(fidp); %reads a single FFT in the SFDB file, sft is the FFT of the data 
     
        if feof(fidp)~=0  
            break
        end
        kchunk=kchunk+1;
        ii=ii+1;
        
        if kchunk == 1
            %header information of the SFDB files
            %einstein=header.einstein; %use for check
            dfr=header.deltanu;                % inverse of the time baseline
            Tfft=header.tbase;                 % time baseline for fft can be 1024,2048,4096,8192 s
            k1=floor(freq12(:,1)/dfr)+1;        % index of the frequency 
            k2=floor(freq12(:,2)/dfr);
         
            %fr1=(k1-1)*dfr   % k1,freq(1),header.deltanu,fr1 %use for check
            %fr2=k2*dfr
            %fprintf('k1,k2= %d,%d,%f,%f \n',k1,k2,fr1,fr2)
        
            lfftin=header.nsamples*2 %number of samples of the input FFT
            nn=lfftin*header.tsamplu/dtout %dtout output sampling time. no sampling dtout=1, nn is the chunck of samples handled for each fft...if BSD is sampled at 10 Hz the original FFT length is multiplied by 10 (20480=10*2048!!!)
            %nn=round(nn)
            t0=header.mjdtime;               % time of the first sample of the file in mjd and gps 
            gpst0=header.gps_sec;           
            %lenx=k2-k1+1;                     %lenght of sft band use for checks
            %t1=-10^6;
            gpst1=-10^6;                      %inizialization of the time of the first sample (fake time)
            halftfft=header.tbase/2;          %half of the FFT time (Tfft/2)
 
            %nn1=2^ceil(log2(lenx(1))+1);
            %nn=lfftout0;
            %if nn1 > nn
            %    disp('   Reduce the output sampling time')
            %end
            n4=nn/4;   % a quarter of the chunck of samples nn
            n2=nn/2;    % half of the chunck of samples nn
%           dt=1/(nn*dfr)
            subsampfact=dtout/header.tsamplu;      %ratio  of the new sampling time to the original
                        %valid ONLY for simulation part! skip this
            %%%%%%%%%%%%%
            %Fs = 4096; 1/Ts       %change            % Sampling frequency 2*fmax, for Tfft=1024s->fmax=2048 Hz-> Fs=4096Hz
            Ts =header.tsamplu;                     % Sampling period
            L = Tfft/Ts;                     % Length of signal
            t = (0:L-1)*Ts;                % Time
            fsinus=101.2932;
            f2=108.674;
            %%%%%%%%%%%%%
        
        end
        
        %t2=t1;
        gpst2=gpst1;        % is initialized by a negative number in order to avoid the condition hole > dtout at the first sample used in case of holes
                            
        %t1=header.mjdtime; %should change for each fft, used for checks
        gpst1=header.gps_sec; % gps time of the first sample in the fft
        n4s=n4+1;
%       hole=diff_mjd(t2,t1)-halftfft;
        hole=gpst1-gpst2-halftfft;    %distance from one sft to the half of the next
        %%%%%%%%%%%%%%%loop for holes control %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        if hole > dtout
            n4s=1;
            if hole < halftfft/2
                fprintf('warning hole=%f ,kcunck=%d', hole,kchunk)
                ihole=round(hole/dtout);                           %length of the hole in samples
                n4s=n4-ihole+1;                                    % new n4s variable if a hole is present
            end
        end
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       T1=diff_mjd(t0,t1); 
        T1=gpst1-gpst0;          
        ig=floor(T1/dtout)+n4s;  %index of the chuck to be placed in the the gd matrix. Correspond to the gpstime of the fft shifted by a quarter (coherently with FFT interlacement) 
% 
        itimes(kchunk,1)=ig;        %used to check the times of the FFTs and the index output
        itimes(kchunk,2)=T1;
        headers(kchunk,:)=header;   %used to check the headers of the FFTs output

        p_eq(kchunk,1)=header.px_eq;      %position of the detector in 
        p_eq(kchunk,2)=header.py_eq;
        p_eq(kchunk,3)=header.pz_eq;

        v_eq(kchunk,1)=header.vx_eq;
        v_eq(kchunk,2)=header.vy_eq;
        v_eq(kchunk,3)=header.vz_eq;
        v_eq(kchunk,4)=header.gps_sec;

        for l=1:ngds %numero di sottobandine 
            switch sim
                case 1
                  %    disp('using simulation data') 

                    x=0.5*exp(1j*2*pi*fsinus*(t+T1))+0.5*exp(1j*2*pi*f2*(t+T1));
                    Y = fft(x);           
                    sftt=Y(k1(l):k2(l));
                case 2
                    %  disp('using real data+sinusoid') 

                    x = 0.01*0.5*exp(1j*2*pi*fsinus*(t+T1))+0.01*0.5*exp(1j*2*pi*f2*(t+T1));  
                    Ys = fft(x);
                    sftt=Ys(k1(l):k2(l))+sft(k1(l):k2(l))'; 
                case 3 %need to check                   
                     %  disp('using analytic signal sampled at twice')
                    sftt1=2*sft(k1(l):k2(l))';          %the amplitude of the FFT of an analytic signal is twice the one of the real one
                    sftt=[sftt1 zeros(1,length(sftt1))];
                otherwise
            %       disp('using reduced-analytic signal')
                    %k1(l), k2(l)
                    sftt=sft(k1(l):k2(l))';
                  
            end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%             if window==1  %e sim diverso da0 caso solo dati o solo sin  %
%                % disp('using windowing')                                %
%                 w=tukeywin(size(sftt,2),0.01);                          %
%                 sftt=sftt.*w';                                          %
%             end                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %per tutti i casi
            
            y=ifft(conj(sftt))/subsampfact; %conj is used in order to have agreement between the FFT definition of MATLAB and the C code that are different
            %n4s,n4,n2
            y=y(n4s:n4+n2);         
            g(l,ig:ig+n2+n4-n4s)=y;
            imax=max(imax,ig+n2+n4-n4s);
        end
    end  
  
    fclose(fidp);
end

g=g(:,1:imax);

%save;
v_eq(:,4)=v_eq(:,4)-v_eq(1,4)+halftfft;
%save 
for l=1:ngds
    pars.t0=t0;
   % pars.t00=floor(t0);
    pars.inifr=freq12(l,1);
    pars.bandw=BSD_BAND;
    pars.v_eq=v_eq;
    p_eq(:,4)=v_eq(:,4);
    pars.p_eq=p_eq;
    pars.Tfft=Tfft;
    pars.ant=ant;
    pars.run=run;
    pars.cal=calibration;
    pars.notes=notes;
    gg=gd(g(l,:));  
%   Tini=mjd2gps(t0);
    gg=edit_gd(gg,'ini',0, 'dx',dtout, 'cont',pars);
    
    a=freq12(l,1);
    b=freq12(l,2);
    a=num2str(a,'%04d');
    b=num2str(b,'%04d');
    
    gdname=strcat(gd_iname,'_',a,'_',b,'_',run)
    eval([gdname '=gg'])
    gdlongname=strcat(foldout,gdname)
    eval(['save ' gdlongname ' ' gdname ]);
end

toc
