function [bsd_out,stpar]=equi_collect(addr,BSD_tab_out,stpar)
% collects data for bsd_equilego
%
%    addr          path that contains BSD data master directory without the final dirsep
%                    or structure with all the input parameters as fields
%    BSD_tab_out   BSD table (charged) or just the name (char)
%    stpar
%       .modif     if exist field modif, modif is used. BE SURE TO CLEAR IT
%       .modifpost if exist field modifpost, modifpost is used. BE SURE TO CLEAR IT

% Snag Version 2.0 - April 2021
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni and S. Frasca - sergio.frasca@roma1.infn.it
% Department of Physics - Sapienza University - Rome

if isfield(stpar,'modif')
    modif=stpar.modif;
else
    modif=0;
end
if isfield(stpar,'modifpost')
    modifpost=stpar.modifpost;
end
MODE=stpar.subtab.n_f;
stpar.MODE=MODE;

Nfft=stpar.Nfft;
T_ini=stpar.T_ini;
T_fin=stpar.T_fin;
Dt_max=stpar.Dt_max;
fact=stpar.fact;
st_n1=floor(stpar.st_n/fact);
dt0=stpar.dt0;
dt1=stpar.dt1;
% % % nout=ceil((T_fin-T_ini)*86400/dt1)+1;
% % % stpar.nout=nout;
% % % y(1:nout)=0;
% % % y=y(:);

if MODE == 2
    disp('  MODE 2')
    [bsd_out,parout,stpar]=bsd_interband_equilego(addr,BSD_tab_out,stpar,modif)
    stpar.stds=parout;
else
    disp('  MODE 1')
    for i = 1:stpar.subtab.n_t
        in=load_tab_bsd(addr,BSD_tab_out,i,modif)
        stds.in(i)=std(in);
        in=edit_gd(in,'n',Nfft);
        if stpar.frshift ~= 0
            in=bsd_freqshift(in,stpar.frshift,T_ini)
        end
        cont=cont_gd(in);
        t0=cont.t0;
        stpar.ant=cont.ant;
        stpar.run=cont.run;
        stpar.cal=cont.cal;
%         if i == 1
%             t00=t0;
%         end
        tdif=diff_mjd(T_ini,t0);
        ndif=round(tdif/dt0);
        ndif1=ceil(ndif/fact)*fact;
        ddif=round(ndif1-ndif);
        t1=t0+ddif*dt0/86400;
        stpar.t1(i)=t1;
%         kbias=round((t1-T_ini)*86400/dt1);
        [in,nsampcut]=bsd_trim(in,t1);nsampcut
        in=edit_gd(in,'n',Nfft);
        sb=bsd_subband_lego(in,stpar);
        stds.out(i)=std(sb);
% % %         nsb=n_gd(sb);
% % %         y1=y_gd(sb);
% % %         y(kbias+1:kbias+nsb)=y1;
        if isfield(cont,'tfstr')
            if isfield(cont.tfstr,'zeros')
                sb=bsd_zeroholes(sb);
            end
        end
        if exist('modifpost','var')
            sb=bsd_acc_modif(sb,modifpost);
        end
        ysb=y_gd(sb);
        ysb(st_n1(i):Nfft/fact)=0;
        sb=edit_gd(sb,'y',ysb);
        if i == 1
            bsd_out=sb; 
        else
            bsd_out=conc_bsd(bsd_out,sb)
        end
    end
    stpar.stds=stds;
% % %     ncut=(t00-T_ini)*86400/dt1;
% % %     y=y(ncut+1:end);
% % %     stpar.bsd_out=edit_gd(bsd_out,'y',y);
end
