function [bsd_out,BSD_tab_out,out]=bsd_extr_event(addr,tabl,ev,band,wid)
% data extraction around an event
%    the data are extracted around the exact minute of the event
%
%    addr      path that contains BSD data master directory without the final dirsep
%    tabl      table of basic input data (loaded; typ. BSD_O3_L)
%    ev        event (in mjd or name in the form, e.g., 'GW190521_074359'
%    band      default [30 320]
%    wid       width in minutes on each side (def 5); if length(wid)=2, the two values 
%               are the distance in seconds around the event

% Snag Version 2.0 - February 2021
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni and S. Frasca - sergio.frasca@roma1.infn.it
% Department of Physics - Sapienza University - Rome

if ~isnumeric(ev)
    ev=GW2mjd(ev);
end
if ~exist('band','var')
    band=[30 320];
end
if ~exist('wid','var')
    wid=5;
end

if length(wid) == 1
    mjd_day=floor(ev);
    mjd_min=floor((ev-mjd_day)*1440)/1440;
    t1=mjd_day+mjd_min-wid/1440; mjd2s(t1)
    t2=mjd_day+mjd_min+wid/1440; mjd2s(t2)
    tev=(ev-t1)*86400;
    ini=-wid*60;
else
    t1=ev+wid(1)/86400;
    t2=ev+wid(2)/86400;
    ini=wid(1);
    tev=(ev-t1)*86400;
end

[bsd_out,BSD_tab_out,out]=bsd_lego(addr,tabl,'OO',[t1 t2],band,3);

bsd_out=edit_gd(bsd_out,'ini',ini);

out.t1=t1;
out.t2=t2;
out.tev=tev;