function outmul=NC_crea_DC3(bsdsstr,cands,header,tail,NCcom)
% creates a type 3 non-coherent DB
% 
%     outmul=NC_crea_DC3(bsdsstr,cands,header,tail,NCcom)
%
%   bsdsstr  bsd search structure array (with addr,tab  as for bsd_equilego)
%              if it is a cell array containing bsds, use them
%   cands    list of sources (cell array)
%   header   of the files (ex: 'GC')
%   tail     filnam tail
%
%   NCcom
%      frbase   bsd frequency base (def 10)
%      wband    sub-band division (0.5,1,2,5,10 Hz; default 1 Hz)
%      sband    search band (in units of 1/SD; default 20) sband=0 -> 20
%      interl   interlacing delay (in 1/SD); default sband/2, if sband = 20, interl = 5
%      enl      enlargement factor (def 1)
%      nsid     number of sidereal bins (def or 0 = round(SD/outsid.DT))
%
%      sol      if exists and >0 -> also solar (NYI)
%      checksolar  if exist and = 1, substitutes SD with SolD
%                  if > 1, substitutes SD with checksolar
%
%      nweek    if present and >0, t-fr mode, n week for pieces (typically 1)
%      dweek    week interlacing delay (<= nweek, def nweek/2, =nweek or 0 no interlacing)

% Snag Version 2.0 - May 2020
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni, S.D'Antonio and S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

tic
out.start=datetime('now');

if ~exist('NCcom','var')
    NCcom=struct();
end

if isfield(NCcom,'frbase')
    frbase=NCcom.frbase;
else
    frbase=10;
end

ncands=length(cands);

% runame=bsdsstr(1).runame;
filnam=NC_filnam(3,header,'cand',tail)

for i = 1:ncands
    cand=cands{i};
    sids{i}=NC_sid_sweep_multi(bsdsstr,cand,cand.f0,NCcom);
    str.Dtime=toc
    outmul.cand{i}=cand;
    outmul.sids{i}=sids{i};
end

outmul.Dtime=toc
save(filnam,'outmul','-v7.3')