function out=NC_crea_DC2(addr,tab,direc,band,header,NCcom)
% creates a type 2 non-coherent DB
%
%     out=NC_crea_DC2(addr,tab,direc,band,header,NCcom)
%
%   addr,tab  as for bsd_equilego
%   direc   direction structure
%   band    min,max frequency bands (any value inside the first and the second
%   header  of the files (ex: 'GC')
%
%   NCcom
%      frbase   bsd frequency base (def 10)
%      wband    sub-band division (0.5,1,2,5,10 Hz; default 1 Hz)
%      sband    search band (in units of 1/SD; default 20) sband=0 -> 20
%      interl   interlacing delay (in 1/SD); default sband/2, if sband = 20, interl = 5
%      enl      enlargement factor (def 1)
%      nsid     number of sidereal bins (def or 0 = round(SD/outsid.DT))
%
%      sol      if exists and >0 -> also solar (NYI)
%      checksolar  if exist and = 1, substitutes SD with SolD
%                  if > 1, substitutes SD with checksolar
%
%      nweek    if present and >0, t-fr mode, n week for pieces (typically 1)
%      dweek    week interlacing delay (<= nweek, def nweek/2, =nweek or 0 no interlacing)

% Snag Version 2.0 - May 2020
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni, S.D'Antonio and S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

tic
tabn=inputname(2);
tabn=tabn(5:end);
out.start=datetime('now');

if ~exist('NCcom','var')
    NCcom=struct();
end

NCcom.nweek=1;

if isfield(NCcom,'frbase')
    frbase=NCcom.frbase;
else
    frbase=10;
end

if strcmp(direc,'nodirec') && ~isfield(NCcom,'wband')
    NCcom.wband=10;
end

bands=floor(band(1)/frbase)*frbase:frbase:ceil(band(2)/frbase)*frbase;
nbands=length(bands)-1;

maxNCT = maxNumCompThreads;
NCT=min(maxNCT,nbands)

str=cell(1,nbands);
sidsw=cell(1,nbands);

pp=parpool('local',NCT);

parfor i = 1:nbands
    sidsw{i}=NC_sid_sweep(addr,tab,direc,(bands(i)+bands(i+1))/2,NCcom)
    bandout=bands(i:i+1);
    str{i}.filnam=NC_filnam(2,header,tabn,bandout)
    str{i}.Dtime=toc
end
delete(gcp)

for i = 1:nbands
    sidsw0=sidsw{i};
    out.band{i}=str{i};
    save(filnam,'sidsw0')
end

out.Dtime=toc